.. _api_astro:

********************
astro - Astrophysics
********************

.. currentmodule:: gammapy.astro

.. automodapi:: gammapy.astro.darkmatter
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.astro.population
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.astro.source
    :no-inheritance-diagram:
    :include-all-objects:
